import React from 'react'
import { commonSettings, switchSettings, elementSettings } from './otherSettings'
import {
  GroupOutlined,
  EditOutlined,
  FormOutlined,
  FieldBinaryOutlined,
  HighlightOutlined,
  FieldTimeOutlined,
  LinkOutlined,
} from '@ant-design/icons'

const base = {
  groupBase: {
    title: '基础信息',
    type: 'object',
    properties: {}
  },
  $id: {
    title: '字段名称',
    type: 'string',
    widget: 'FieldNames',
    required: true,
    displayType: 'row',
    labelWidth: 80,
  },
  title: {
    title: '标题',
    required: true,
    type: 'string',
    widget: 'htmlInput',
    displayType: 'row',
    labelWidth: 80,
  },
  placeholder: {
    title: '提示语',
    type: 'string',
    displayType: 'row',
    labelWidth: 80,
  },
  presetValue: {
    title: '默认值',
    type: 'string',
    widget: 'InputDefault',
    displayType: 'row',
    labelWidth: 80,
  },
}

const groupStyle = {
  groupStyle: {
    title: '控件样式',
    type: 'object',
    properties: {}
  },
  width: {
    title: '元素宽度',
    type: 'string',
    widget: 'percentSlider',
  },
  labelWidth: {
    title: '标签宽度',
    description: '默认值110',
    default: 110,
    type: 'number',
    widget: 'slider',
    max: 400,
    props: {
      hideNumber: true,
    },
  },
}

const layoutWidgets = [
  {
    text: '分组名称',
    name: '分组名称',
    icon: <GroupOutlined />,
    schema: {
      title: '分组名称',
      type: 'object',
      // theme: 'collapse:pure',
      // properties: {
      //   title: {
      //     title: '标题',
      //     type: 'string',
      //     required: true,
      //     displayType: 'row',
      //     labelWidth: 80,
      //   },
      // },
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      title: {
        title: '标题',
        type: 'string',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
    },
  },
]

const textWidgets = [
  {
    text: '文本',
    name: '文本',
    icon: <EditOutlined />,
    schema: {
      title: '文本',
      type: 'string',
      widget: 'TextInput',
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {},
        default: null
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
        default: '请输入内容'
      },
      presetValue: {
        title: '默认值',
        type: 'string',
        widget: 'InputDefault',
        displayType: 'row',
        labelWidth: 80,
      },
      groupVerify: {
        title: '数据校验',
        type: 'object',
        properties: {}
      },
      maxLength: {
        title: '字节最大长度',
        type: 'number',
        widget: 'number',
        default: 200,
        displayType: 'row',
        labelWidth: 100,
      },
      rules: {
        title: '正则校验',
        type: 'array',
        default: [],
        widget: 'VerifyTextInput',
        displayType: 'row',
        labelWidth: 100,
      },
      uniqueVerify: {
        title: '唯一值校验',
        type: 'string',
        widget: 'select',
        enum: ['表名/字段名'],
        default: null,
        enumNames: ['表名/字段名'],
        displayType: 'row',
        labelWidth: 100,
        props: {
          allowClear: true
        }
      },
      tableName: {
        title: '表名',
        type: 'string',
        hidden: "{{formData.uniqueVerify !== '表名/字段名'}}",
        displayType: 'row',
        labelWidth: 100,
        dependencies: ['uniqueVerify'],
      },
      fieldName: {
        title: '字段名',
        type: 'string',
        hidden: "{{formData.uniqueVerify !== '表名/字段名'}}",
        displayType: 'row',
        labelWidth: 100,
        dependencies: ['uniqueVerify'],
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      required: {
        title: '必填',
        type: 'boolean',
        default: false,
        width: '33%',
        props: {
          style: {
            marginLeft: '10px',
          }
        }
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      isStoreID: {
        title: '是否存储ID',
        type: 'boolean',
        default: false,
        hidden: "{{!['【本人姓名】','【本人部门】'].includes(rootValue.presetValue) }}",
        dependencies: ['presetValue'],
      },
      isQRCode: {
        title: '设备二维码',
        type: 'boolean',
        widget: 'BooleanSwitch',
        default: false,
        displayType: 'row',
        labelWidth: 120,
        description: '是否解析为二维码格式(手持端专用)',
      },
      description: {
        title: '说明',
        type: 'string',
        displayType: 'row',
        labelWidth: 55,
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      addonBefore: {
        title: '前置标签',
        type: 'string',
        widget: 'InputAddon',
        displayType: 'row',
        labelWidth: 80,
      },
      addonAfter: {
        title: '后置标签',
        type: 'string',
        widget: 'InputAddon',
        displayType: 'row',
        labelWidth: 80,
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
  {
    text: '多行文本',
    name: '多行文本',
    icon: <FormOutlined />,
    schema: {
      title: '多行文本',
      type: 'string',
      widget: 'TextArea'
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
        default: '请输入内容'
      },
      presetValue: {
        title: '默认值',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
      },
      groupVerify: {
        title: '数据校验',
        type: 'object',
        properties: {}
      },
      maxLength: {
        title: '最大长度',
        type: 'number',
        widget: 'number',
        default: 500,
        displayType: 'row',
        labelWidth: 100,
        description: '可输入最大字节长度'
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      required: {
        title: '必填',
        type: 'boolean',
        default: false,
        width: '40%',
        props: {
          style: {
            marginLeft: '10px'
          }
        }
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      currentAddress: {
        title: '获取当前地址',
        type: 'boolean',
        widget: 'BooleanSwitch',
        default: false,
        displayType: 'row',
        labelWidth: 120,
        description: '是否自动获取当前地址(手持端专用)',
      },
      description: {
        title: '说明',
        type: 'string',
        displayType: 'row',
        labelWidth: 55,
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      rows: {
        title: '高度',
        description: '多行文本占据的行数',
        type: 'number',
        widget: 'number',
        max: 10,
        default: 5,
        widget: 'slider',
        props: {
          hideNumber: true,
        },
      },
      width: {
        title: '元素宽度',
        description: '默认值100%',
        type: 'string',
        widget: 'percentSlider',
        default: '100%',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
  {
    text: '数值',
    name: '数值',
    icon: <FieldBinaryOutlined />,
    schema: {
      title: '数值',
      type: 'number',
      widget: 'NumberInput',
      presetValue: 0,
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        // widget: 'Placeholder',
        displayType: 'row',
        labelWidth: 80,
        // dependencies: ['title']
      },
      presetValue: {
        title: '默认值',
        type: 'number',
        widget: 'NumerDefault',
        displayType: 'row',
        labelWidth: 80,
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      required: {
        title: '必填',
        type: 'boolean',
        default: false,
        width: '40%',
        props: {
          style: {
            marginLeft: '10px'
          }
        }
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      description: {
        title: '说明',
        type: 'string',
        displayType: 'row',
        labelWidth: 55,
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      prefix: {
        title: '前缀',
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 60,
      },
      formatter: {
        title: '格式化',
        type: 'string',
        displayType: 'row',
        labelWidth: 60,
        widget: 'select',
        enum: ['%', '‰'],
        default: '',
        enumNames: ['%', '‰'],
        props: {
          allowClear: true
        }
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
  {
    text: '富文本',
    name: '富文本',
    icon: <HighlightOutlined />,
    schema: {
      title: '富文本',
      type: 'string',
      widget: 'RichText',
      width: '100%',
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      presetValue: {
        title: '默认值',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      required: {
        title: '必填',
        type: 'boolean',
        default: false,
        width: '40%',
        props: {
          style: {
            marginLeft: '10px'
          }
        }
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      description: {
        title: '说明',
        type: 'string',
        displayType: 'row',
        labelWidth: 55,
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
  {
    text: '编码',
    name: '编码',
    schema: {
      title: '编码',
      type: 'string',
      widget: 'Coding',
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      // presetValue: {
      //   title: '默认值',
      //   type: 'string',
      //   displayType: 'row',
      //   labelWidth: 80,
      // },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      required: {
        title: '必填',
        type: 'boolean',
        default: false,
        width: '40%',
        props: {
          style: {
            marginLeft: '10px'
          }
        }
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: true,
        width: '30%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      prefixion: {
        title: '前缀',
        type: 'string',
        displayType: 'row',
        labelWidth: 90,
      },
      codingType: {
        title: '编码方式',
        type: 'string',
        displayType: 'row',
        labelWidth: 90,
        widget: 'select',
        enum: ['1', '2', '3'],
        default: '3',
        enumNames: ['前缀-年份-六位编码', '前缀-年份月份-六位编码', '前缀 -八位编码'],
        description: '{{rootValue.codingType === "1" ?"示例:XJ-2019-000001" : (rootValue.codingType === "2" ? "示例: XJ-201909-000001" : "示例: XJ00000001")}}'
      },
      description: {
        title: '说明',
        type: 'string',
        displayType: 'row',
        labelWidth: 90,
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  }
]

const selectWidgets = [
  {
    text: '下拉框',
    name: '下拉框',
    schema: {
      title: '下拉框',
      type: 'string',
      widget: 'ComboBox',
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        default: '点击下拉选择内容',
        displayType: 'row',
        labelWidth: 80,
      },
      presetValue: {
        title: '默认值',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
      },
      groupSource: {
        title: '数据来源',
        type: 'object',
        properties: {}
      },
      sourceType: {
        title: '来源方式',
        name: '下拉框',
        type: 'string',
        widget: 'SourceType',
        default: '手动输入',
        displayType: 'row',
        labelWidth: 80,
      },
      options: {
        title: '',
        name: '选项',
        type: 'array',
        required: '{{formData.sourceType === "手动输入"}}',
        hidden: '{{formData.sourceType !== "手动输入"}}',
        default: [],
        widget: 'simpleList',
        items: {
          type: 'object',
          properties: {
            value: {
              title: '选项值',
              type: 'string',
              displayType: 'row',
              labelWidth: 75,
              required: true,
              default: '',
              props: {
                style: {
                  width: '120px',
                  color: 'blue'
                }
              }
            },
          },
        },
        props: {
          // hideMove: true,
          hideCopy: true,
        },
        displayType: 'row',
        labelWidth: 80,
        dependencies: ['sourceType']
      },
      dictionary: {
        title: '{{formData.sourceType}}',
        name: '{{formData.sourceType}}',
        required: '{{formData.sourceType === "数据字典"}}',
        hidden: '{{formData.sourceType !== "数据字典"}}',
        type: 'string',
        widget: 'Dictionary',
        value: '{{formData.sourceType !== "数据字典" ? null : ""}}',
        displayType: 'row',
        labelWidth: 80,
        dependencies: ['sourceType']
      },
      tableName: {
        title: '表名',
        name: '表名',
        required: '{{formData.sourceType === "表数据"}}',
        hidden: '{{formData.sourceType !== "表数据"}}',
        type: 'string',
        widget: 'TableName',
        displayType: 'row',
        labelWidth: 80,
        dependencies: ['sourceType'],
      },
      fieldName: {
        title: '字段名',
        name: '字段名',
        required: true,
        required: '{{formData.sourceType === "表数据"}}',
        hidden: '{{formData.sourceType !== "表数据"}}',
        type: 'string',
        widget: 'FieldName',
        displayType: 'row',
        labelWidth: 80,
        dependencies: ['sourceType', 'tableName'],
      },
      isMySite: {
        title: '仅显示本人所属的站点',
        name: '仅显示本人所属的站点',
        required: true,
        default: false,
        // description: '勾选后仅显示本人所属的站点',
        hidden: '{{formData.sourceType !== "站点"}}',
        type: 'boolean',
        widget: 'checkbox',
        props: {
          style: {
            paddingLeft: '10px'
          }
        }
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      required: {
        title: '必填',
        type: 'boolean',
        default: false,
        width: '33%',
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      isMultiple: {
        title: '多选',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
        hidden: '{{formData.isEdit}}'
      },
      isSearch: {
        title: '搜索',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
        default: true
      },
      isEdit: {
        title: '是否可编辑',
        type: 'boolean',
        widget: 'BooleanSwitch',
        displayType: 'row',
        labelWidth: 120,
        description: '勾选后可直接输入选项,可编辑选择仅支持多选',
        hidden: '{{formData.sourceType !== "手动输入"}}'
      },
      description: {
        title: '说明',
        type: 'string',
        displayType: 'row',
        labelWidth: 55,
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    }
  },
  {
    text: '单选框',
    name: '单选框',
    schema: {
      title: '单选框',
      name: '单选框',
      type: 'string',
      widget: 'RadioButton',
      require: true,
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      presetValue: {
        title: '默认值',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
      },
      groupSource: {
        title: '数据来源',
        type: 'object',
        properties: {}
      },
      sourceType: {
        title: '来源方式',
        name: '单选框',
        type: 'string',
        widget: 'SoruceType',
        default: '手动输入',
        displayType: 'row',
        labelWidth: 80,
      },
      options: {
        title: '',
        name: '选项',
        type: 'array',
        required: '{{formData.sourceType === "手动输入"}}',
        hidden: '{{formData.sourceType !== "手动输入"}}',
        default: [],
        widget: 'simpleList',
        items: {
          type: 'object',
          properties: {
            value: {
              title: '选项值',
              type: 'string',
              displayType: 'row',
              labelWidth: 75,
              // required: true,
              default: '',
              props: {
                style: {
                  width: '120px',
                  color: 'blue'
                }
              }
            },
          },
        },
        props: {
          // hideMove: true,
          hideCopy: true,
        },
        displayType: 'row',
        labelWidth: 80,
      },
      dictionary: {
        title: '{{formData.sourceType}}',
        name: '{{formData.sourceType}}',
        required: '{{formData.sourceType === "数据字典"}}',
        hidden: '{{formData.sourceType !== "数据字典"}}',
        type: 'string',
        widget: 'Dictionary',
        value: '{{formData.sourceType !== "数据字典" ? null : ""}}',
        displayType: 'row',
        labelWidth: 80,
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '40%',
        props: {
          style: {
            marginLeft: '10px',
          }
        }
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      description: {
        title: '说明',
        type: 'string',
        displayType: 'row',
        labelWidth: 55,
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    }
  },
  {
    text: '复选框',
    name: '复选框',
    schema: {
      title: '复选框',
      name: '复选框',
      type: 'string',
      widget: 'CheckBox',
      require: true,
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      presetValue: {
        title: '默认值',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
      },
      groupSource: {
        title: '数据来源',
        type: 'object',
        properties: {}
      },
      sourceType: {
        title: '来源方式',
        name: '复选框',
        type: 'string',
        widget: 'SoruceType',
        default: '手动输入',
        displayType: 'row',
        labelWidth: 80,
        props: {
          disabled: true
        }
      },
      options: {
        title: '',
        name: '选项',
        type: 'array',
        required: '{{formData.sourceType === "手动输入"}}',
        hidden: '{{formData.sourceType !== "手动输入"}}',
        default: [],
        widget: 'simpleList',
        items: {
          type: 'object',
          properties: {
            value: {
              title: '选项值',
              type: 'string',
              displayType: 'row',
              labelWidth: 75,
              // required: true,
              default: '',
              props: {
                style: {
                  width: '120px',
                  color: 'blue'
                }
              }
            },
          },
        },
        props: {
          // hideMove: true,
          hideCopy: true,
        },
        displayType: 'row',
        labelWidth: 80,
      },
      dictionary: {
        title: '{{formData.sourceType}}',
        name: '{{formData.sourceType}}',
        required: '{{formData.sourceType === "数据字典"}}',
        hidden: '{{formData.sourceType !== "数据字典"}}',
        type: 'string',
        widget: 'Dictionary',
        value: '{{formData.sourceType !== "数据字典" ? null : ""}}',
        displayType: 'row',
        labelWidth: 80,
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '40%',
        props: {
          style: {
            marginLeft: '10px',
          }
        }
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      description: {
        title: '说明',
        type: 'string',
        displayType: 'row',
        labelWidth: 55,
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    }
  },
  {
    text: '开关',
    name: '开关',
    schema: {
      title: '开关',
      name: '开关',
      type: 'number',
      widget: 'SwitchSelector',
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      presetValue: {
        title: '默认值',
        type: 'boolean',
        widget: 'BooleanSwitch',
        displayType: 'row',
        labelWidth: 80,
      },
      // placeholder: {
      //   title: '提示语',
      //   type: 'string',
      //   displayType: 'row',
      //   labelWidth: 80,
      //   default: '请输入位置'
      // },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      showText: {
        title: '显示文字',
        type: 'string',
        widget: 'select',
        enum: ['开/关', '是/否', '明/暗'],
        enumNames: ['开/关', '是/否', '明/暗'],
        displayType: 'row',
        labelWidth: 80,
        props: {
          allowClear: true
        }
      },
      description: {
        title: '说明',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
  {
    text: '关联选择',
    name: '关联选择',
    schema: {
      title: '关联选择',
      name: '关联选择',
      type: 'string',
      widget: 'RelevanceSelect',
      require: true,
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
        default: '请选择内容',
      },
      presetValue: {
        title: '默认值',
        type: 'string',
        displayType: 'row',
        widget: 'CascadeDefault',
        labelWidth: 80,
        dependencies: ['sourceType']
      },
      groupSource: {
        title: '数据来源',
        type: 'object',
        properties: {}
      },
      fieldParent: {
        title: '父字段名',
        type: 'string',
        required: true,
        widget: 'FieldNames',
        displayType: 'row',
        labelWidth: 80,
      },
      dictionary: {
        title: '数据字典',
        name: '数据字典',
        required: true,
        type: 'string',
        widget: 'Dictionary',
        displayType: 'row',
        labelWidth: 80,
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      description: {
        title: '说明',
        type: 'string',
        displayType: 'row',
        labelWidth: 55,
      },
      ...groupStyle,
    }
  },
  {
    text: '级联选择',
    name: '级联选择',
    schema: {
      title: '级联选择',
      name: '级联选择',
      type: 'string',
      widget: 'CascadeSelector',
      require: true,
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        default: '点击下拉选择内容',
        displayType: 'row',
        labelWidth: 80,
      },
      presetValue: {
        title: '默认值',
        type: 'string',
        widget: 'CascadeDefault',
        displayType: 'row',
        labelWidth: 80,
        // dependencies: ['sourceType']
      },
      groupSource: {
        title: '数据来源',
        type: 'object',
        properties: {}
      },
      sourceType: {
        title: '来源方式',
        name: '来源方式',
        type: 'string',
        widget: 'select',
        default: '城市数据',
        enum: ['城市数据'],
        enumNames: ['城市数据'],
        displayType: 'row',
        labelWidth: 80,
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '40%',
        props: {
          style: {
            marginLeft: '10px',
          }
        }
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      description: {
        title: '说明',
        type: 'string',
        displayType: 'row',
        labelWidth: 55,
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    }
  },
]

const businessWidgets = [
  {
    text: '人员选择器',
    name: '人员选择器',
    schema: {
      title: '人员选择器',
      type: 'string',
      widget: 'PersonSelector',
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        default: '点击选择人员',
        displayType: 'row',
        labelWidth: 80,
      },
      presetValue: {
        title: '默认值',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
      },
      groupSource: {
        title: '数据来源',
        type: 'object',
        properties: {}
      },
      role: {
        title: '机构角色',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
      },
      isMySite: {
        title: '本人站点',
        name: '本人站点',
        required: true,
        default: false,
        type: 'boolean',
        widget: 'checkbox',
        props: {
          style: {
            paddingLeft: '10px'
          }
        }
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      isMultiple: {
        title: '多选',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      isStoreID: {
        title: '是否存储ID',
        type: 'boolean',
        default: false,
      },
      description: {
        title: '说明',
        type: 'string',
        displayType: 'row',
        labelWidth: 55,
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      interactiveType: {
        title: '交互方式',
        type: 'string',
        widget: 'select',
        enum: ['下拉框', '分组模态', '树形模态'],
        default: '下拉框',
        enumNames: ['下拉框', '分组模态', '树形模态'],
        displayType: 'row',
        labelWidth: 80,
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    }
  },
  {
    text: '部门选择器',
    name: '部门选择器',
    schema: {
      title: '部门选择器',
      type: 'string',
      widget: 'DeptSelector',
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        default: '点击选择部门',
        displayType: 'row',
        labelWidth: 80,
      },
      presetValue: {
        title: '默认值',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      isMultiple: {
        title: '多选',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      isStoreID: {
        title: '是否存储ID',
        type: 'boolean',
        default: false,
      },
      description: {
        title: '说明',
        type: 'string',
        displayType: 'row',
        labelWidth: 55,
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    }
  },
  {
    text: '台账选择器',
    name: '台账选择器',
    schema: {
      title: '台账选择器',
      type: 'string',
      widget: 'AccountSelector',
      require: true,
      displayType: 'row',
      labelWidth: 120,
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        default: '点击输入框弹出选择框',
        displayType: 'row',
        labelWidth: 80,
      },
      presetValue: {
        title: '默认值',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
      },
      groupSource: {
        title: '数据来源',
        type: 'object',
        properties: {}
      },
      accountName: {
        title: '台账名称',
        name: '台账名称',
        type: 'string',
        widget: 'AccountName',
        displayType: 'row',
        labelWidth: 100,
        required: true,
      },
      fieldshine: {
        title: '映射字段',
        name: '映射字段',
        type: 'array',
        widget: 'Fieldshine',
        displayType: 'row',
        labelWidth: 100,
        required: true,
        dependencies: ['accountName', '$id'],
        default: [],
        description: '单字段映射支持多选，多字段映射仅支持单选',
      },
      siteFilter: {
        title: '站点过滤',
        name: '站点过滤',
        type: 'boolean',
        default: false,
        displayType: 'row',
        labelWidth: 100,
        widget: 'BooleanSwitch',
        description: '开启后只显示自己所属站点数据',
      },
      isMultiple: {
        title: '多选',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        displayType: 'row',
        labelWidth: 100,
        widget: 'BooleanSwitch',
        hidden: '{{formData.fieldshine.length !== 1}}',
      },
      sql: {
        title: 'SQL过滤',
        name: 'SQL过滤',
        type: 'string',
        widget: 'textarea',
        props: {
          placeholder: '示例：部门="XX部门"'
        }
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      required: {
        title: '必填',
        type: 'boolean',
        default: false,
        width: '31%',
        props: {
          style: {
            marginLeft: '10px',
          }
        }
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '23%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '23%',
      },
      description: {
        title: '说明',
        type: 'string',
        displayType: 'row',
        labelWidth: 55,
        widget: 'input',
      },
      ...groupStyle,
    }
  }
]

const dateWidgets = [
  {
    text: '日期选择',
    name: '日期选择',
    schema: {
      title: '日期选择',
      type: 'string',
      widget: 'DateTime',
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
        default: '请选择日期',
      },
      // presetValue: {
      //   title: '默认值',
      //   type: 'string',
      //   widget: 'DateDefault',
      //   dateFormat: '{{formData.format}}',
      //   displayType: 'row',
      //   labelWidth: 80,
      //   description: '勾选默认当前日期此处配置无效'
      // },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '40%',
        props: {
          style: {
            marginLeft: '10px',
          }
        }
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      format: {
        title: '日期格式',
        type: 'string',
        enum: ['date', 'dateTime', 'year', 'month', 'week', 'quarter'],
        default: 'date',
        enumNames: ['日期', '日期时间', '日期年份', '日期月份', '日期周', '日期季度'],
        displayType: 'row',
        labelWidth: 80,
      },
      options: {
        title: '选项',
        type: 'string',
        widget: 'select',
        enum: ['默认为空', '默认为当前时间', '不超过当前时间'],
        default: '默认为空',
        enumNames: ['默认为空', '默认为当前时间', '不超过当前时间'],
        displayType: 'row',
        labelWidth: 80,
        // props: {
        //   allowClear: true
        // }
      },
      // defaultCurrent: {
      //   title: '默认当前日期',
      //   type: 'boolean',
      //   widget: 'checkbox',
      //   default: false,
      //   width: '50%',
      //   props: {
      //     style: {
      //       marginLeft: '10px',
      //     }
      //   }
      // },
      // currentDate: {
      //   title: '不超过当前日期',
      //   type: 'boolean',
      //   widget: 'checkbox',
      //   default: false,
      //   width: '50%',
      //   props: {
      //     style: {
      //       marginLeft: '10px',
      //     }
      //   }
      // },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
  {
    text: '时间选择',
    name: '时间选择',
    icon: <FieldTimeOutlined />,
    schema: {
      title: '时间选择',
      type: 'string',
      widget: 'Time',
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
        default: '请选择时间',
      },
      presetValue: {
        title: '默认值',
        type: 'string',
        widget: 'TimeDefault',
        format: '{{formData.format}}',
        displayType: 'row',
        labelWidth: 80,
        description: '勾选默认当前时间此处配置无效'
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {},
      },
      // format: {
      //   title: '日期格式',
      //   type: 'string',
      //   enum: ['date', 'dateTime', 'year', 'month', 'week', 'quarter'],
      //   default: 'date',
      //   enumNames: ['日期', '日期时间', '日期年份', '日期月份', '日期周', '日期季度'],
      //   displayType: 'row',
      //   labelWidth: 80,
      // },
      options: {
        title: '选项',
        type: 'string',
        widget: 'select',
        enum: ['默认为空', '默认为当前时间', '不超过当前时间'],
        default: '默认为空',
        enumNames: ['默认为空', '默认为当前时间', '不超过当前时间'],
        displayType: 'row',
        labelWidth: 80,
      },
      description: {
        title: '说明',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
        widget: 'input',
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '40%',
        props: {
          style: {
            marginLeft: '10px',
          }
        }
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      // defaultCurrent: {
      //   title: '默认当前时间',
      //   type: 'boolean',
      //   widget: 'checkbox',
      //   default: false,
      //   width: '50%',
      //   props: {
      //     style: {
      //       marginLeft: '10px',
      //     }
      //   }
      // },
      // currentDate: {
      //   title: '不超过当前时间',
      //   type: 'boolean',
      //   widget: 'checkbox',
      //   default: false,
      //   width: '50%',
      // },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    }
  },
]

const fileWidgets = [
  {
    text: '附件',
    name: '附件',
    icon: <LinkOutlined />,
    schema: {
      title: '附件',
      type: 'string',
      widget: 'FileUpload',
      width: '100%'
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      fileType: {
        title: '文件类型',
        type: 'string',
        required: true,
        widget: 'select',
        enum: ['全部', '图片', '文档', '音频', '视频'],
        enumNames: ['全部', '图片', '文档', '音频', '视频'],
        default: '全部',
        displayType: 'row',
        labelWidth: 100,
        // description: "{{formData.fileType === '图片' ? '支持bmp、gif、jpeg、tiff、png、svg、jpg格式': (formData.fileType === '文档' ? '支持docx，xlsx，pdf格式':(formData.fileType === '音频' ? '支持mp3格式' : (formData.fileType === '视频' ? '支持mp4格式'：null )))}}",
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      preview: {
        title: '预览',
        type: 'boolean',
        widget: 'checkbox',
        default: true,
        width: '33%',
      },
      download: {
        title: '下载',
        type: 'boolean',
        widget: 'checkbox',
        default: true,
        width: '33%',
      },
      photo: {
        title: '允许从相册选取',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        hidden: "{{!['图片','音频', '视频'].includes(formData.fileType)}}"
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      // showType: {
      //   title: '显示方式',
      //   type: 'string',
      //   default: 'picture',
      //   enum: ['picture', 'text', 'picture-card'],
      //   enumNames: ['列表_详细', '列表_省略', '卡片'],
      // },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
]

const mapWidgets = [
  {
    text: '坐标控件',
    name: '坐标控件',
    schema: {
      title: '坐标控件',
      type: 'string',
      widget: 'Coordinate',
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
        default: '请选择坐标位置'
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      description: {
        title: '说明',
        type: 'string',
        displayType: 'row',
        labelWidth: 55,
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
  {
    text: '设备选择',
    name: '设备选择',
    schema: {
      title: '设备选择',
      type: 'string',
      widget: 'Device',
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
        default: '请选择设备'
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      description: {
        title: '说明',
        type: 'string',
        displayType: 'row',
        labelWidth: 55,
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
  {
    text: '位置坐标',
    name: '位置坐标',
    schema: {
      title: '位置坐标',
      type: 'string',
      widget: 'SearchLocation',
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
        default: '请输入位置'
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      description: {
        title: '说明',
        type: 'string',
        displayType: 'row',
        labelWidth: 55,
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
  // {
  //   "text": "复杂结构样例",
  //   "name": "something",
  //   "schema": {
  //     "title": "对象",
  //     "description": "这是一个对象类型",
  //     // "type": "object",
  //     type: 'array',
  //     items: {
  //       "properties": {
  //         "GIS编码": {
  //           "title": "GIS编码",
  //           "type": "string"
  //         },
  //         "GIS图层": {
  //           "title": "GIS图层",
  //           "type": "string",
  //         },
  //       }
  //     },

  //   }
  // }
]

const advancedWidgets = [
  {
    text: '关联表单',
    name: '关联表单',
    schema: {
      title: '',
      type: 'string',
      widget: 'RelationForm',
      width: '100%',
      controlShow: '',
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      titleShow: {
        title: '标题',
        type: 'string',
        widget: 'htmlInput',
        default: '关联表单',
        displayType: 'row',
        labelWidth: 80,
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
        props: {
          style: {
            marginLeft: '10px'
          }
        }
      },
      // hidden: {
      //   title: '隐藏',
      //   type: 'boolean',
      //   widget: 'checkbox',
      //   default: false,
      //   width: '33%',
      // },
      description: {
        title: '说明',
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 60,
      },
      groupSource: {
        title: '数据来源',
        type: 'object',
        properties: {}
      },
      accountName: {
        title: '台账名称',
        type: 'string',
        widget: 'AccountName',
        displayType: 'row',
        labelWidth: 80,
        required: true
      },
      mappedField: {
        title: '映射字段',
        type: 'array',
        widget: 'MappedField',
        displayType: 'row',
        labelWidth: 80,
        required: true,
        default: [],
        dependencies: ['accountName'],
      },
      defaultShow: {
        title: '默认显示',
        type: 'boolean',
        widget: 'BooleanSwitch',
        default: true,
        displayType: 'row',
        labelWidth: 80,
      },
      controlShow: {
        title: '控制规则',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
        widget: 'ControlRules',
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值10',
        default: 10,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
  {
    text: '自动计算',
    name: '自动计算',
    schema: {
      title: '自动计算',
      type: 'number',
      widget: 'AutoCalculate',
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      // placeholder: {
      //   title: '提示语',
      //   type: 'string',
      //   displayType: 'row',
      //   labelWidth: 80,
      // },
      presetValue: {
        title: '默认值',
        type: 'number',
        widget: 'NumerDefault',
        displayType: 'row',
        labelWidth: 80,
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      required: {
        title: '必填',
        type: 'boolean',
        default: false,
        width: '40%',
        props: {
          style: {
            marginLeft: '10px'
          }
        }
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: true,
        width: '30%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      description: {
        title: '说明',
        type: 'string',
        displayType: 'row',
        labelWidth: 55,
      },
      groupSource: {
        title: '数据来源',
        type: 'object',
        properties: {},
      },
      calculateRule: {
        title: '计算规则',
        type: 'string',
        widget: 'CalculateRule',
        displayType: 'row',
        labelWidth: 80,
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      // prefix: {
      //   title: '前缀',
      //   type: 'string',
      //   widget: 'htmlInput',
      //   displayType: 'row',
      //   labelWidth: 60,
      // },
      // formatter: {
      //   title: '格式化',
      //   type: 'string',
      //   displayType: 'row',
      //   labelWidth: 60,
      //   widget: 'select',
      //   enum: ['%', '‰'],
      //   default: '',
      //   enumNames: ['%', '‰'],
      //   props: {
      //     allowClear: true
      //   }
      // },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
]

const settings = [
  {
    title: '布局控件',
    color: 'pink',
    props: {
      style: {
        color: 'red'
      }
    },
    widgets: layoutWidgets
  },
  {
    title: '文本控件',
    widgets: textWidgets
  },
  {
    title: '选择器控件',
    widgets: selectWidgets,
  },
  {
    title: '业务控件',
    widgets: businessWidgets,
  },
  {
    title: '时间控件',
    show: true,
    widgets: dateWidgets,
  },
  {
    title: '附件控件',
    show: true,
    useCommon: true,
    widgets: fileWidgets,
  },
  {
    title: 'GIS控件',
    show: true,
    widgets: mapWidgets,
  },
  {
    title: '高级控件',
    widgets: advancedWidgets,
  },
]

export default settings