import { message } from 'antd'
import { isObject } from '../../utils'
import { formAutomaticComputation } from '../../apis/process'

export const debounce = (fn) => {
  let t = null
  return function (e) {
    const context = this
    const args = arguments
    if (t) {
      clearTimeout(t)
    }
    t = setTimeout(function () {
      fn.call(context, ...args)
    }, 300)
  }
}

//json值结构转化为数组值
export const jsonToValues = (data, paths) => {
  let formValue = []
  Object.keys(data).map((k) => {
    if (isObject(data[k])) {
      Object.keys(data[k]).map((key) => {
        formValue.push({ fieldName: key, fieldValue: data[k][key] + '' })
      })
    }
  })
  let values = []
  if (Array.isArray(paths)) {
    paths.forEach(v => {
      let fieldName = v.split('.')[1]
      let fieldValue = '0'
      let item = formValue.find(s => s.fieldName === fieldName)
      if (item) {
        fieldValue = item.fieldValue
      }
      values.push({
        fieldName,
        fieldValue,
      })
    })
  }
  return {
    formValue: values,
    relationForm: data.relationForm
  }
}

const getRules = (json) => {
  let AutoCalculate = []
  let parent = json?.properties
  if (isObject(parent)) {
    for (let v in parent) {
      let child = parent[v]?.properties
      if (isObject(child)) {
        for (let s in child) {
          if (child[s].widget === 'AutoCalculate') {
            AutoCalculate.push({
              filedName: s,
              ...child[s],
              targetPath: `${v}.${s}`,
            })
          }
        }
      }
    }
  }
  return AutoCalculate
}

const getPath = (json, filed) => {
  let parent = json?.properties
  if (isObject(parent)) {
    for (let v in parent) {
      let child = parent[v]?.properties
      if (isObject(child)) {
        for (let s in child) {
          if (s === filed) {
            return `${v}.${s}`
          }
        }
      }
    }
  }
  return ''
}

const getFieldName = (configs, tableName) => {
  let filedName = []
  configs.forEach(v => {
    if (v['台账名称'] === tableName) {
      filedName.push(v.fieldName)
    }
  })
  return filedName
}

const automaticComputation = async (params) => {
  if ((new Date().getTime() - params.startTime) < 1000) return
  let param = {
    tableName: params.tableName,
    filedFormulas: params.filedFormulas,
    relationForm: params.relationForm,
    values: jsonToValues(params.form.getValues(), params.paths).formValue
  }
  const { code, data, msg } = await formAutomaticComputation(param)
  if (code === 0) {
    if (Array.isArray(data)) {
      data.forEach(v => {
        let path = getPath(params.schema, v.fieldName)
        if (path) {
          params.form.setValueByPath(path, v.fieldValue)
        }
      })
    }
  } else {
    message.error(msg)
  }
}

const setValue = debounce(automaticComputation)

export const getWatch = (schema, form, startTime) => {
  let watch = {}
  let { relationForm } = form?.getValues()
  const configs = relationForm?.configs || []
  if (Array.isArray(configs)) {
    configs.forEach(v => {
      v['台账名称'] = v.accountName
      v['映射字段'] = v.mappedField
    })
  }
  const AutoCalculate = getRules(schema)
  if (Array.isArray(AutoCalculate)) {
    AutoCalculate.forEach(item => {
      const { filedName, rules, calculateRule } = item
      let paths = []
      if (Array.isArray(rules)) {
        rules.forEach(s => {
          let item = { tableName: null, fields: [] }
          if (schema.tableName === s.tableName) {
            item = s
          } else {
            item = { fields: getFieldName(configs, s.tableName) }
          }
          if (item) {
            if (Array.isArray(item.fields)) {
              item.fields.forEach(v => {
                let path = getPath(schema, v)
                if (path) {
                  paths.push(path)
                }
              })
            }
          }
        })
      }
      if (Array.isArray(paths)) {
        paths.forEach(v => {
          watch[v] = () => {
            let params = {
              tableName: schema.tableName,
              filedFormulas: [{ fieldName: filedName, formula: calculateRule }],
              form: form,
              paths: paths,
              relationForm,
              schema: schema,
              startTime
            }
            setValue(params)
          }
        })
      }
    })
  }
  return watch
}

export default getWatch